@@ -11,6 +11,7 @@ fn test_match(query: &str, source: &str) {
 #[test]
 fn test_cpp_pattern() {
   test_match("$A->b()", "expr->b()");
+  test_match("if (a) { $$$VERYLONGNAME }", "if (a) { a;b;c; }");
   test_match("expr->$B()", "expr->b()");
   test_match("ns::ns2::$F()", "ns::ns2::func()");
   test_match("template <typename $T>", "template <typename T>");
@@ -30,5 +31,14 @@ fn test_replace(src: &str, pattern: &str, replacer: &str) -> Result<String, TSPa
 fn test_cpp_replace() -> Result<(), TSParseError> {
   let ret = test_replace("expr->b()", "$A->b()", "func($A)->b()")?;
   assert_eq!(ret, "func(expr)->b()");
+  let ret = test_replace("if (a) { a;b;c; }", "if (a) { $$$A }", "$$$A")?;
+  assert_eq!(ret, "a;b;c;");
+  // https://stackoverflow.com/questions/78663351
+  let ret = test_replace(
+    "if (a) { a;b;c; }",
+    "if (a) { $$$VERYLONGNAME }",
+    "$$$VERYLONGNAME",
+  )?;
+  assert_eq!(ret, "a;b;c;");
   Ok(())
 }
